package com.paxdroid.os;

interface IPaxDeviceManager {
    /**
     * ###### NOTE: new AIDL interface must appended to the end of this file. ######
     */
    /**
     * Get Device's TSN(Terminal Serial Number).
     */
    String getDeviceTSN();
    /**
     * Get system formatted custom version number.
     */
    String getFormattedCustomVersion();
    /**
     * Reset status bar
     */
    void resetStatusBar();
    /**
     * Show or hide the status bar.
     * @param invisible true to hide the status bar, false to show the status bar.
     */
    void setStatusBarInvisible(boolean invisible);
    /**
     * Return true if Status Bar is invisible.
     * @return true if Status Bar is invisible.
     */
    boolean isStatusBarInvisible();
    /**
     * Show or hide the navigation bar.
     * @param invisible True to hide the navigation bar, false to show the navigation bar.
     */
    void setNavigationBarInvisible(boolean invisible);
    /**
     * Return true if Navigation Bar is invisible.
     * @return true if Navigation Bar is invisible.
     */
    boolean isNavigationBarInvisible();
    /**
     * disable or enable StatusBar.
     * @param disable True to set StatusBar disable, false to set StatusBar enable.
     */
    void setStatusBarDisable(boolean disable);
    /**
     * Return true if StatusBar is disabled.
     * @return true if StatusBar is disabled.
     */
    boolean isStatusBarDisabled();
    /**
     * Set NavigationBar(including BACK, HOME, RECENT) to be disable or enable.
     * @param disable true to set NavigationBar disable, false to set NavigationBar enable.
     */
    void setNavigationBarDisable(boolean disable);
    /**
     * Return true if NavigationBar is disabled.
     * @return true if NavigationBar is disabled.
     */
    boolean isNavigationBarDisabled();
    /**
     * Enable or disable BACK key.
     * @param disable true to set BACK key disable, false to set BACK Key enable.
     */
    void setBackKeyDisable(boolean disable);
    /**
     * Return true if BACK key is disabled.
     * @return true if BACK key is disabled.
     */
    boolean isBackKeyDisabled();
    /**
     * Enable or disable RECENT key.
     * @param disable true to set RECENT key disable, false to set RECENT key enable.
     */
	void setRecentKeyDisable(boolean disable);
    /**
     * Return true if RECENT key is disabled.
     * @return true if RECENT key is disabled.
     */
    boolean isRecentKeyDisabled();
    /**
     * Enable or disable HOME key.
     * @param disable true to set HOME key disable, false to set HOME key enable.
     */
	void setHomeKeyDisable(boolean disable);
    /**
     * Return true if HOME key is disabled.
     * @return true if HOME key is disabled.
     */
    boolean isHomeKeyDisabled();
    /**
     * Enable or disable POWER key.
     * @param disable true to set POWER key disable, false to set POWER key enable.
     */
    void setPowerKeyDisable(boolean disable);
    /**
     * Return true if POWER key is disabled.
     * @return true if POWER key is disabled.
     */
    boolean isPowerKeyDisabled();
    /**
     * @param unconditional true to enter "the default launcher" without showing a chooser dialog.
     */
    void setEnterDefaultLauncherUnconditional(boolean unconditional);
    /**
     * Return true if allowing system to start "the default launcher" without
     * showing a chooser dialog even there are several launchers.
     */
    boolean isEnterDefaultLauncherUnconditional();
    /**
     * return the default launcher's package name in system.
     */
    String getDefaultLauncherPackageName();
    /**
     * return the default launcher's activity name in system.
     */
    String getDefaultLauncherActivityName();
    /**
     * Reboot system without reason.
     */
    void reboot();
    /** NOTE: Only support to check the packages under /data/app/
     * @param packageName , the name of the package to be checked
     * @param permission , the permission to be checked
     * @return true 1 the permission is granted, or 0 if the permission is denied.
     */
    int checkPermission(in byte [] packageName, in byte [] permission);
    // Network
    /**
     * Change APN.
     * @return 1 success.
     */
    int forceCMWapConnection(in String newAPN, in String userName, in String passwd);
    /**
     * @param title , input pin keyboard title
     */
    void setPedTitle(String title);
    /**
     * @param amount, input pin keyboard ,consumption amount
     */
    void setPedAmount(String amount);
    /**
     * @param policy
     * Always : 2
     * Only when plugged in : 1
     * Never : 0
     */
    void setWifiSleepPolicy(int policy);
    /**
     * @param need, 
     * ture : into Settings needs password
     */
    void setSettingsNeedPassword(boolean need);
    /**
     * Shutdown system without reason.
     */
    void shutdown();
    /**
     * Place a new service into the service manager.
     * @param name the name of the new service
     * @param service the service object
     */
    void addService(String name, IBinder service);
    /**
     * @param display 
     * true: display pin body '*'
     * false:not display
     */
    void setDisplayPedBody(boolean display);
    /**
     * wipe data
     */
    void recovery();
    /**
     * Enable or disable share network.
     * @param enable to enable Mobile data.
     */
    void setShareNetworkEnabled(boolean enabled);
    /**
     * Return true if share network is enabled.
     * @return true if share network is enabled.
     */
    boolean isShareNetworkEnabled();
    /**
     * Enable or disable Mobile data.
     * @return true if successful.
     * @param enable to enable Mobile data.
     */
    void setMobileDataEnabled(boolean enabled);
    /**
     * Return true if Mobile data is enabled.
     * @return true if Mobile data is enabled.
     */
    boolean isMobileDataEnabled();
    /**
     * Returns a reference to a service with the given name.
     * @param name the name of the service to get
     * @return a reference to the service, or null if the service doesn't exist
     */
    IBinder getService(String name);
    /**
     * Retrieve an existing service called @a name from the
     * service manager.  Non-blocking.
     */
    IBinder checkService(String name);
    /**
     * Return a list of all currently running services.
     */
    String[] listServices();
    /**
     * @param mode
     *          0: update firmware
     *          1: update apk
     * @param source
     *          the source to be updated.
     * @return non-zero if update fail.
     * **********************************************************************
     * NOTE: *** This may block, so DO NOT called update() in Main Thread ***
     * **********************************************************************
     */
    int update(int mode, String source);

    /**
     * backup the given 'pkgName' package to 'zipPath'.
     */
    int packageDataBackup(String pkgName, String zipPath);
    /**
     * restore the pkgName's package data from 'zipPath'.
     */
    int packageDataRestore(String pkgName, String zipPath);

}
